#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-z-xml-light
version:              3.10.2
package-name:         pandoc
lib-name:             xml-light
id:                   pandoc-3.10.2-B2toS54O7pmILLBPUaMmbP-xml-light
key:                  pandoc-3.10.2-B2toS54O7pmILLBPUaMmbP-xml-light
license:              GPL-2.0-or-later
copyright:            (c) 2006-2024 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another.  The formats it can handle include

    - light markup formats (many variants of Markdown,
    reStructuredText, AsciiDoc, Org-mode, Muse, Textile,
    txt2tags, djot)
    - HTML formats (HTML 4 and 5)
    - Ebook formats (EPUB v2 and v3, FB2)
    - Documentation formats (GNU TexInfo, Haddock, Vimdoc)
    - Roff formats (man, ms)
    - TeX formats (LaTeX, ConTeXt)
    - Typst
    - XML formats (DocBook 4 and 5, JATS, TEI Simple, OpenDocument)
    - Outline formats (OPML)
    - Bibliography formats (BibTeX, BibLaTeX, CSL JSON, CSL YAML,
    RIS)
    - Word processor formats (Docx, RTF, ODT)
    - Interactive notebook formats (Jupyter notebook ipynb)
    - Page layout formats (InDesign ICML)
    - Wiki markup formats (MediaWiki, DokuWiki, TikiWiki, TWiki,
    Vimwiki, XWiki, ZimWiki, Jira wiki, Creole)
    - Slide show formats (LaTeX Beamer, PowerPoint, Slidy,
    reveal.js, Slideous, S5, DZSlides)
    - Data formats (CSV and TSV tables, Excel spreadsheets)
    - PDF (via external programs such as pdflatex or wkhtmltopdf)

    Pandoc can convert mathematical content in documents
    between TeX, MathML, Word equations, roff eqn, typst,
    and plain text. It includes a powerful system for automatic
    citations and bibliographies, and it can be customized
    extensively using templates, filters, and custom readers
    and writers written in Lua.

    For the pandoc command-line program, see the
    @pandoc-cli@ package.

category:             Text
abi:                  ab0e413069ac6f15d958aacfe5804378
exposed-modules:
    Text.Pandoc.XML.Light Text.Pandoc.XML.Light.Output
    Text.Pandoc.XML.Light.Proc Text.Pandoc.XML.Light.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-3.10.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-3.10.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-3.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc
hs-libraries:         HSpandoc-3.10.2-B2toS54O7pmILLBPUaMmbP-xml-light
depends:
    base-4.18.2.1 containers-0.6.7 text-2.0.2
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-BJAPIc3ZpEX9Hl5GLrN5ZY
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:   /usr/share/doc/haskell-pandoc/html/pandoc.haddock
haddock-html:         /usr/share/doc/haskell-pandoc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc
version:              3.10.2
visibility:           public
id:                   pandoc-3.10.2-15eUPAStvtpHMRHQmrwZVt
key:                  pandoc-3.10.2-15eUPAStvtpHMRHQmrwZVt
license:              GPL-2.0-or-later
copyright:            (c) 2006-2024 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another.  The formats it can handle include

    - light markup formats (many variants of Markdown,
    reStructuredText, AsciiDoc, Org-mode, Muse, Textile,
    txt2tags, djot)
    - HTML formats (HTML 4 and 5)
    - Ebook formats (EPUB v2 and v3, FB2)
    - Documentation formats (GNU TexInfo, Haddock, Vimdoc)
    - Roff formats (man, ms)
    - TeX formats (LaTeX, ConTeXt)
    - Typst
    - XML formats (DocBook 4 and 5, JATS, TEI Simple, OpenDocument)
    - Outline formats (OPML)
    - Bibliography formats (BibTeX, BibLaTeX, CSL JSON, CSL YAML,
    RIS)
    - Word processor formats (Docx, RTF, ODT)
    - Interactive notebook formats (Jupyter notebook ipynb)
    - Page layout formats (InDesign ICML)
    - Wiki markup formats (MediaWiki, DokuWiki, TikiWiki, TWiki,
    Vimwiki, XWiki, ZimWiki, Jira wiki, Creole)
    - Slide show formats (LaTeX Beamer, PowerPoint, Slidy,
    reveal.js, Slideous, S5, DZSlides)
    - Data formats (CSV and TSV tables, Excel spreadsheets)
    - PDF (via external programs such as pdflatex or wkhtmltopdf)

    Pandoc can convert mathematical content in documents
    between TeX, MathML, Word equations, roff eqn, typst,
    and plain text. It includes a powerful system for automatic
    citations and bibliographies, and it can be customized
    extensively using templates, filters, and custom readers
    and writers written in Lua.

    For the pandoc command-line program, see the
    @pandoc-cli@ package.

category:             Text
abi:                  de9c5c327e6cdd6a1d77d1b1f174107e
exposed:              True
exposed-modules:
    Text.Pandoc Text.Pandoc.App Text.Pandoc.Asciify Text.Pandoc.Chunks
    Text.Pandoc.Citeproc Text.Pandoc.Class Text.Pandoc.Class.IO
    Text.Pandoc.Data Text.Pandoc.Emoji Text.Pandoc.Error
    Text.Pandoc.Extensions Text.Pandoc.Filter Text.Pandoc.Format
    Text.Pandoc.Highlighting Text.Pandoc.ImageSize Text.Pandoc.Logging
    Text.Pandoc.MIME Text.Pandoc.MediaBag Text.Pandoc.Options
    Text.Pandoc.PDF Text.Pandoc.Parsing Text.Pandoc.Process
    Text.Pandoc.Readers Text.Pandoc.Readers.AsciiDoc
    Text.Pandoc.Readers.BibTeX Text.Pandoc.Readers.CSV
    Text.Pandoc.Readers.CommonMark Text.Pandoc.Readers.Creole
    Text.Pandoc.Readers.CslJson Text.Pandoc.Readers.Djot
    Text.Pandoc.Readers.DocBook Text.Pandoc.Readers.Docx
    Text.Pandoc.Readers.DokuWiki Text.Pandoc.Readers.EPUB
    Text.Pandoc.Readers.EndNote Text.Pandoc.Readers.FB2
    Text.Pandoc.Readers.HTML Text.Pandoc.Readers.Haddock
    Text.Pandoc.Readers.Ipynb Text.Pandoc.Readers.JATS
    Text.Pandoc.Readers.Jira Text.Pandoc.Readers.LaTeX
    Text.Pandoc.Readers.Man Text.Pandoc.Readers.Markdown
    Text.Pandoc.Readers.Mdoc Text.Pandoc.Readers.MediaWiki
    Text.Pandoc.Readers.Muse Text.Pandoc.Readers.Native
    Text.Pandoc.Readers.ODT Text.Pandoc.Readers.OPML
    Text.Pandoc.Readers.Org Text.Pandoc.Readers.Pod
    Text.Pandoc.Readers.Pptx Text.Pandoc.Readers.RIS
    Text.Pandoc.Readers.RST Text.Pandoc.Readers.RTF
    Text.Pandoc.Readers.TWiki Text.Pandoc.Readers.Textile
    Text.Pandoc.Readers.TikiWiki Text.Pandoc.Readers.Txt2Tags
    Text.Pandoc.Readers.Typst Text.Pandoc.Readers.Vimwiki
    Text.Pandoc.Readers.Xlsx Text.Pandoc.Scripting
    Text.Pandoc.SelfContained Text.Pandoc.Shared Text.Pandoc.Slides
    Text.Pandoc.Sources Text.Pandoc.Templates Text.Pandoc.Transforms
    Text.Pandoc.Translations Text.Pandoc.Translations.Types
    Text.Pandoc.UTF8 Text.Pandoc.Version Text.Pandoc.Writers
    Text.Pandoc.Writers.ANSI Text.Pandoc.Writers.AnnotatedTable
    Text.Pandoc.Writers.AsciiDoc Text.Pandoc.Writers.BBCode
    Text.Pandoc.Writers.BibTeX Text.Pandoc.Writers.ChunkedHTML
    Text.Pandoc.Writers.CommonMark Text.Pandoc.Writers.ConTeXt
    Text.Pandoc.Writers.CslJson Text.Pandoc.Writers.Djot
    Text.Pandoc.Writers.DocBook Text.Pandoc.Writers.Docx
    Text.Pandoc.Writers.DokuWiki Text.Pandoc.Writers.EPUB
    Text.Pandoc.Writers.FB2 Text.Pandoc.Writers.HTML
    Text.Pandoc.Writers.Haddock Text.Pandoc.Writers.ICML
    Text.Pandoc.Writers.Ipynb Text.Pandoc.Writers.JATS
    Text.Pandoc.Writers.Jira Text.Pandoc.Writers.LaTeX
    Text.Pandoc.Writers.Man Text.Pandoc.Writers.Markdown
    Text.Pandoc.Writers.Math Text.Pandoc.Writers.MediaWiki
    Text.Pandoc.Writers.Ms Text.Pandoc.Writers.Muse
    Text.Pandoc.Writers.Native Text.Pandoc.Writers.ODT
    Text.Pandoc.Writers.OOXML Text.Pandoc.Writers.OPML
    Text.Pandoc.Writers.OpenDocument Text.Pandoc.Writers.Org
    Text.Pandoc.Writers.Powerpoint Text.Pandoc.Writers.RST
    Text.Pandoc.Writers.RTF Text.Pandoc.Writers.Shared
    Text.Pandoc.Writers.TEI Text.Pandoc.Writers.Texinfo
    Text.Pandoc.Writers.Textile Text.Pandoc.Writers.Txt2Tags
    Text.Pandoc.Writers.Typst Text.Pandoc.Writers.Vimdoc
    Text.Pandoc.Writers.XML Text.Pandoc.Writers.XWiki
    Text.Pandoc.Writers.ZimWiki Text.Pandoc.XML

hidden-modules:
    Text.Pandoc.App.CommandLineOptions Text.Pandoc.App.Input
    Text.Pandoc.App.Opt Text.Pandoc.App.OutputSettings
    Text.Pandoc.Class.CommonState Text.Pandoc.Class.PandocMonad
    Text.Pandoc.Class.PandocIO Text.Pandoc.Class.PandocPure
    Text.Pandoc.Class.Sandbox Text.Pandoc.Filter.Environment
    Text.Pandoc.Filter.JSON Text.Pandoc.Parsing.Capabilities
    Text.Pandoc.Parsing.Citations Text.Pandoc.Parsing.General
    Text.Pandoc.Parsing.GridTable Text.Pandoc.Parsing.Lists
    Text.Pandoc.Parsing.Math Text.Pandoc.Parsing.Smart
    Text.Pandoc.Parsing.State Text.Pandoc.Parsing.Future
    Text.Pandoc.Readers.Docx.Lists Text.Pandoc.Readers.Docx.Combine
    Text.Pandoc.Readers.Docx.Parse
    Text.Pandoc.Readers.Docx.Parse.Styles Text.Pandoc.Readers.Docx.Util
    Text.Pandoc.Readers.Docx.Symbols Text.Pandoc.Readers.Docx.Fields
    Text.Pandoc.Readers.OOXML.Shared Text.Pandoc.Readers.Pptx.Parse
    Text.Pandoc.Readers.Pptx.Shapes Text.Pandoc.Readers.Pptx.Slides
    Text.Pandoc.Readers.Pptx.SmartArt Text.Pandoc.Readers.Xlsx.Parse
    Text.Pandoc.Readers.Xlsx.Cells Text.Pandoc.Readers.Xlsx.Sheets
    Text.Pandoc.Readers.HTML.Parsing Text.Pandoc.Readers.HTML.Table
    Text.Pandoc.Readers.HTML.TagCategories
    Text.Pandoc.Readers.HTML.Types Text.Pandoc.Readers.LaTeX.Inline
    Text.Pandoc.Readers.LaTeX.Citation Text.Pandoc.Readers.LaTeX.Lang
    Text.Pandoc.Readers.LaTeX.Macro Text.Pandoc.Readers.LaTeX.Math
    Text.Pandoc.Readers.LaTeX.Parsing Text.Pandoc.Readers.LaTeX.SIunitx
    Text.Pandoc.Readers.LaTeX.Table Text.Pandoc.Readers.Mdoc.Lex
    Text.Pandoc.Readers.Mdoc.Macros Text.Pandoc.Readers.Mdoc.Standards
    Text.Pandoc.Readers.Typst.Parsing Text.Pandoc.Readers.Typst.Math
    Text.Pandoc.Readers.ODT.Base Text.Pandoc.Readers.ODT.Namespaces
    Text.Pandoc.Readers.ODT.StyleReader
    Text.Pandoc.Readers.ODT.ContentReader
    Text.Pandoc.Readers.ODT.Generic.Fallible
    Text.Pandoc.Readers.ODT.Generic.SetMap
    Text.Pandoc.Readers.ODT.Generic.Utils
    Text.Pandoc.Readers.ODT.Generic.Namespaces
    Text.Pandoc.Readers.ODT.Generic.XMLConverter
    Text.Pandoc.Readers.ODT.Arrows.State
    Text.Pandoc.Readers.ODT.Arrows.Utils
    Text.Pandoc.Readers.Org.BlockStarts Text.Pandoc.Readers.Org.Blocks
    Text.Pandoc.Readers.Org.DocumentTree
    Text.Pandoc.Readers.Org.ExportSettings
    Text.Pandoc.Readers.Org.Inlines Text.Pandoc.Readers.Org.Meta
    Text.Pandoc.Readers.Org.ParserState Text.Pandoc.Readers.Org.Parsing
    Text.Pandoc.Readers.Org.Shared Text.Pandoc.Readers.Metadata
    Text.Pandoc.Readers.Roff Text.Pandoc.Readers.Roff.Escape
    Text.Pandoc.Readers.XML Text.Pandoc.Writers.Docx.OpenXML
    Text.Pandoc.Writers.Docx.StyleMap Text.Pandoc.Writers.Docx.Table
    Text.Pandoc.Writers.Docx.Types Text.Pandoc.Writers.GridTable
    Text.Pandoc.Writers.JATS.References Text.Pandoc.Writers.JATS.Table
    Text.Pandoc.Writers.JATS.Types Text.Pandoc.Writers.LaTeX.Caption
    Text.Pandoc.Writers.LaTeX.Notes Text.Pandoc.Writers.LaTeX.Table
    Text.Pandoc.Writers.LaTeX.Lang Text.Pandoc.Writers.LaTeX.Types
    Text.Pandoc.Writers.LaTeX.Citation Text.Pandoc.Writers.LaTeX.Util
    Text.Pandoc.Writers.Markdown.Table
    Text.Pandoc.Writers.Markdown.Types
    Text.Pandoc.Writers.Markdown.Inline Text.Pandoc.Writers.Roff
    Text.Pandoc.Writers.Blaze
    Text.Pandoc.Writers.Powerpoint.Presentation
    Text.Pandoc.Writers.Powerpoint.Output Text.Pandoc.Char
    Text.Pandoc.TeX Text.Pandoc.URI Text.Pandoc.XMLFormat
    Text.Pandoc.CSS Text.Pandoc.CSV Text.Pandoc.RoffChar
    Text.Pandoc.UUID Text.Pandoc.Image Text.Pandoc.Citeproc.BibTeX
    Text.Pandoc.Citeproc.Name Text.Pandoc.Citeproc.CslJson
    Text.Pandoc.Citeproc.Data Text.Pandoc.Citeproc.Locator
    Text.Pandoc.Citeproc.MetaValue Text.Pandoc.Citeproc.Util
    Paths_pandoc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-3.10.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-3.10.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-3.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc
hs-libraries:         HSpandoc-3.10.2-15eUPAStvtpHMRHQmrwZVt
depends:
    Glob-0.10.2-46NEPXotEWf6uAZhl3ly9w
    JuicyPixels-3.3.9-Idzob9Lz4fHEXh55nHHNbA
    aeson-2.2.2.0-6vy5nFkYOklEBUzF5CRv7u
    aeson-pretty-0.8.11-BvvDjbHwDAyFeHzC2HVANG array-0.5.6.0
    asciidoc-0.1.0.4-2aoXQkCWyfwI3lB1Iv1s8H
    attoparsec-0.14.4-5xxMJ7hMTSZEwvbcpfcCWS base-4.18.2.1
    base64-bytestring-1.2.1.0-JBjEAAOdpBm2IYrolgjJx9 binary-0.8.9.1
    blaze-html-0.9.2.0-17FkYPGue7ZAHMHHyLr7B4
    blaze-markup-0.8.3.0-8nAkqh6ULumKoXEFXqqlfH bytestring-0.11.5.3
    case-insensitive-1.2.1.0-6RlPO9Qfa9fCrnhTKB14aA
    citeproc-0.13.0.1-BridTA4WK10JYkLuOAwi77
    commonmark-0.3-6LcT5hE566UJcq9fqG0WFs
    commonmark-extensions-0.2.7.1-B5tB3EK8Q0Q7IGUyrUosuI
    commonmark-pandoc-0.3-LaxfE6GYeLnAuKwlJlOeqV containers-0.6.7
    crypton-1.0.5-8C2I1Rf6QReJKslsE3zXuF
    crypton-connection-0.4.5-AQb54mRO8a9Efts3pvYr3m
    crypton-x509-system-1.6.8-3taBeIDc7qzGnGaRYvjL1V
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    directory-1.3.8.5 djot-0.1.4.1-9BQCVsiwNew4ynDkkp0eFk
    doclayout-0.5.0.3-19wYOTkFhQj7ga4Iw88MWl
    doctemplates-0.11.0.1-5ZZ8lhNhKbLFInLlyWhMlg
    emojis-0.1.5-2oBg13lskSK9ZqTB2bktt5 exceptions-0.10.7
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    gridtables-0.1.1.0-J0VsZgYLgEQ631krx5XoDY
    haddock-library-1.11.0-HUygwSEabQbAXyi3xPKSkj
    http-client-0.7.19-8AzWSyA06XNDCM9FIBhhTj
    http-client-tls-0.3.6.4-GpdGf98kidO2rAaJB77bKV
    http-types-0.12.4-AW38QdPURmwEzxajknpV4M
    ipynb-0.2-ItnzX6u1QUrDETDZ5Vp0k4
    jira-wiki-markup-1.5.1-L0EOjmEIrh9BS75j9Y3Dw8
    libyaml-0.1.4-2v9xYSjUB5B6Tl1TKTnKnU
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN mtl-2.3.1
    network-3.1.4.0-8HZ2mHT7KyE1ZVQfwLbJCE
    network-uri-2.6.4.2-FHtb4mND2mdHJ6uOX3EAJs
    pandoc-3.10.2-B2toS54O7pmILLBPUaMmbP-xml-light
    pandoc-types-1.23.1.2-GSvb4yy0JYI8h6WGCyx7HL parsec-3.1.16.1
    pretty-1.1.3.6 pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR
    process-1.6.19.0 random-1.2.1.3-GfiOoTkiJ8dHrTrBUL8yXz
    safe-0.3.21-242vtiZp8xiFH4MzHCK9jy
    scientific-0.3.8.1-A5wXYZ7oCLNAWLoDifRRUz
    skylighting-0.14.7-EgkAU0Hh1yw1x4XvimLRo7
    skylighting-core-0.14.7-IkrKaXfheIOIUpvJMymKea
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE
    tagsoup-0.14.8-8kPaXtaYapP8ASwIPYpORz
    temporary-1.3-EJjX5K17BD86XZ5zCqX06b
    texmath-0.13.2.1-Da2zj7NQhrU3hn0lQRh1LM text-2.0.2
    text-conversions-0.3.1.1-1F5hlEOWRiVFeW5LRHgUQS time-1.12.2
    tls-2.0.6-3ztA3Qzcw4kEk662BmhmYx typst-0.11-HhpxTSsxOjPHFGYf5Zr4i6
    unicode-collation-0.1.3.7-DqMg0RmxVHPJ8O4mufjjUp
    unicode-data-0.7.0-7uiL1YfSJ6H42GEaYe0eWJ
    unicode-transforms-0.4.0.1-FGjesECMKXJ9TT9eA5lFcT unix-2.8.4.0
    vector-0.13.2.0-8P1yhfNTE0VJ5EIM0TMJkk
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    yaml-0.11.11.2-CwFCe6z7zbF6EHPQfr57mP
    zip-archive-0.4.3.2-8zBG5otiD7D72dv3IXFor4
    zlib-0.7.1.0-9PtbtAjlwdC8Samdliu9GX

haddock-interfaces:   /usr/share/doc/haskell-pandoc/html/pandoc.haddock
haddock-html:         /usr/share/doc/haskell-pandoc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

